@@ -1,7 +1,9 @@
 from .audio_reader import AudioReader
 from .audio_data import AudioData
+from .audio_writer import AudioWriter
 
 __all__ = [
     "AudioReader",
+    "AudioWriter",
     "AudioData"
 ]
