@@ -2,7 +2,7 @@ from .dense import DenseBlock
 from .inception import InceptionModule
 from .mlp import MLP
 from .residual import ResidualModule, ResidualBlock
-from .transformer import TransformerEncoderBlock, AttentionModule
+from .transformer import TransformerEncoderBlock, AttentionModule, TransformerEncoder
 
 __all__ = [
     "DenseBlock",
